﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Data;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Imaging;
using System.Windows.Navigation;
using System.Windows.Shapes;
using System.Collections.ObjectModel;
using System.Data.SqlClient;
using System.Data;
using System.IO;
using System.Data.SqlTypes;
using Infragistics.Windows.DataPresenter;
using Infragistics.Windows.Editors;
using Infragistics.Windows.Ribbon;
using Infragistics.Windows.Reporting;
using System.Windows.Markup;
using System.Threading;
// using iAnywhere.Data.AsaClient;
using System.Xml;

namespace VSS2XGUI
{
    /// <summary>
    /// Interaction logic for BaseContentControl.xaml
    /// </summary>
    public partial class BaseContentControl : UserControl
    {
        protected ObservableCollection<CColumnProperty> mColumnsMetaData = new ObservableCollection<CColumnProperty>();
       
        protected string mDataSetName;
        protected string mDataTableName;     
        protected DataSet mDBDataSet = new DataSet();
        protected DataView mDBDataView;


        public BaseContentControl()
        {
            ProfilerTimer Timer = new ProfilerTimer("BaseContentControl::BaseContentControl");        

            InitializeComponent();

            Timer.Stop();
        }

        private void BaseContentCtrl_Loaded(object sender, RoutedEventArgs e)
        {
            ProfilerTimer Timer = new ProfilerTimer("BaseContentControl::BaseContentCtrl_Loaded");        

            xamMainDataGrid.Language = XmlLanguage.GetLanguage(Thread.CurrentThread.CurrentCulture.Name);

            ApplyColumnProperties();

            Timer.Stop();
        }

        public void RefreshData(bool fDontAssignDatasourceToGrid)
        {
            ProfilerTimer Timer = new ProfilerTimer("BaseContentControl::RefreshData");
            try
            {                
                Mouse.OverrideCursor = Cursors.Wait;
  
                // Try to get the data from embedded resource files (XMLFiles)
                StoredDataSets StoredDS = new StoredDataSets();
                XmlReader XMLReader = XmlReader.Create(new StringReader(StoredDS.UserAccountsData));
                mDBDataSet.ReadXml(XMLReader);
                mDBDataSet.ReadXmlSchema(XmlReader.Create(new StringReader(StoredDS.UserAccountDataSchema)));

                if (!fDontAssignDatasourceToGrid)
                {
                    xamMainDataGrid.DataSource = mDBDataSet.Tables[0].DefaultView;
                }
            }
            catch (SqlException Ex)
            {
                MessageBox.Show(Ex.ToString());
            }
            catch (Exception Ex)
            {
                MessageBox.Show(Ex.ToString());
            }
            finally
            {
                Mouse.OverrideCursor = null;
            }

            Timer.Stop();
        }


 



        public ObservableCollection<CColumnProperty> ColumnMetaData
        {
            set { mColumnsMetaData = value; }
            get { return mColumnsMetaData; }
        }
        

        protected void ApplyColumnProperties()
        {
            ProfilerTimer Timer = new ProfilerTimer("BaseContentControl::ApplyColumnProperties");

            string columnName = "";
            Visibility ColVisibility = Visibility.Visible;

            foreach (CColumnProperty ColumnProp in mColumnsMetaData)
            {
                columnName = ColumnProp.ColumnName;

                // For test version only
                if (columnName == "Password") continue;

                try
                {
                    if(xamMainDataGrid.FieldLayouts.Count > 0)
                    {
                        // Apply Visibility
                        if (!ColumnProp.IsVisible) 
                            ColVisibility = Visibility.Collapsed;
                        else 
                            ColVisibility = Visibility.Visible;

                        if(xamMainDataGrid.FieldLayouts[0].Fields[columnName].Visibility != ColVisibility)
                            xamMainDataGrid.FieldLayouts[0].Fields[columnName].Visibility = ColVisibility;

                        // Set Scroll Tip
                        xamMainDataGrid.FieldLayouts[0].Fields[columnName].IsScrollTipField = ColumnProp.IsScrollTipField;

                        // Set Column Header
                        xamMainDataGrid.FieldLayouts[0].Fields[columnName].Label = ColumnProp.DisplayName;
                        
                    }
                    if (xamMainDataGrid.FieldLayouts.Count > 0 && xamMainDataGrid.FieldLayouts[0].Fields[columnName].Visibility != ColVisibility)
                        xamMainDataGrid.FieldLayouts[0].Fields[columnName].Visibility = ColVisibility;

                }
                catch (Exception Ex)
                {
                    MessageBox.Show("Column " + columnName + " " + Ex.ToString(), "An Error occured", MessageBoxButton.OK, MessageBoxImage.Error);
                }
            }
            Timer.Stop();
        }

        private void xamMainDataGrid_RecordActivated(object sender, Infragistics.Windows.DataPresenter.Events.RecordActivatedEventArgs e)
        {

        }


        private void xamMainDataGrid_FieldLayoutInitializing(object sender, Infragistics.Windows.DataPresenter.Events.FieldLayoutInitializingEventArgs e)
        {
            /*
            int LayoutIndex = xamMainDataGrid.FieldLayouts.IndexOf(e.FieldLayout);
            if (LayoutIndex == 1)
            {
                // Set background color for child records in hierarchical data grid
                Style s = FindResource("LayoutIdx1Style") as Style;
                e.FieldLayout.Settings.DataRecordCellAreaStyle = s;
            }
            */
        }

        private void xamMainDataGrid_RecordExpanded(object sender, Infragistics.Windows.DataPresenter.Events.RecordExpandedEventArgs e)
        {

        }

        private void xamMainDataGrid_MouseDoubleClick(object sender, MouseButtonEventArgs e)
        {
  
        }

        private void xamMainDataGrid_PreviewKeyUp(object sender, KeyEventArgs e)
        {
            if (e.Key == Key.Enter)
            {
                MessageBox.Show("ENTER-Key catched by xamMainDataGrid_PreviewKeyUp - Event-Hanlder", "XamDataGrid got ENTER");
            }
        }

        private void xamMainDataGrid_KeyUp(object sender, KeyEventArgs e)
        {
            if (e.Key == Key.Enter)
            {
                MessageBox.Show("ENTER-Key catched by xamMainDataGrid_KeyUp - Event-Hanlder", "XamDataGrid got ENTER");
            }
        }


        private void BaseContentCtrl_Initialized(object sender, EventArgs e)
        {            
            HorizontalAlignment = HorizontalAlignment.Stretch;
            VerticalAlignment = VerticalAlignment.Stretch;
            Width = Double.NaN;    // 
            Height = Double.NaN;   //             
        }


        private void xamMainDataGrid_RecordsDeleting(object sender, Infragistics.Windows.DataPresenter.Events.RecordsDeletingEventArgs e)
        {

        }

        private void xamMainDataGrid_RecordsDeleted(object sender, Infragistics.Windows.DataPresenter.Events.RecordsDeletedEventArgs e)
        {

        }


    }

  
}
